eventChannel property
The event channel used to receive audio device change events.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('audio_output_device_check/events');
The event channel used to receive audio device change events.
@visibleForTesting
final eventChannel = const EventChannel('audio_output_device_check/events');