AudioDeviceInfo class

Represents information about an audio output device

Constructors

AudioDeviceInfo({required AudioDeviceType type, required String name})
const
AudioDeviceInfo.fromMap(Map map)
Creates an AudioDeviceInfo from a platform channel map
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The display name of the device
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AudioDeviceType
The detected audio output device type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
Converts this AudioDeviceInfo to a map for platform channels
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override