MethodChannelAudioOutputDeviceCheck class
An implementation of AudioOutputDeviceCheckPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- AudioOutputDeviceCheckPlatform
- MethodChannelAudioOutputDeviceCheck
Constructors
Properties
-
audioDeviceStream
→ Stream<
AudioDeviceInfo> -
Stream of audio device changes
no setteroverride
- eventChannel → EventChannel
-
The event channel used to receive audio device change events.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBluetoothConnectPermissionStatus(
) → Future< BluetoothPermissionStatus> -
override
-
getCurrentDevice(
) → Future< AudioDeviceInfo> -
Gets the current audio output device
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestBluetoothConnectPermission(
) → Future< BluetoothPermissionStatus> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited